@@ -204,13 +204,17 @@ separate_define_relation <- function(
     for(k in 1:length(terms_right[[i]])){
       
       is_already_left <- is_equal_not_null(terms_right[[i]][[k]], sapply(terms, "[[", "term"))
+      if(terms_right[[i]][[k]]==".")
+        is_already_left <- seq_along(terms_right) != i
       is_already_right <- FALSE
       if(length(add_terms)>0)
         is_already_right <- is_equal_not_null(terms_right[[i]][[k]], 
                                               sapply(add_terms, "[[", "term"))
       if(any(is_already_left)){
-        terms[[which(is_already_left)]]$right_from_oz <- 
-          c(terms[[which(is_already_left)]]$right_from_oz, i)
+        for(m in 1:sum(is_already_left)){
+          terms[[which(is_already_left)[m]]]$right_from_oz <- 
+            c(terms[[which(is_already_left)[m]]]$right_from_oz, i) 
+        }
       }else if(any(is_already_right)){
         add_terms[[which(is_already_right)]]$right_from_oz <- 
           c(add_terms[[which(is_already_right)]]$right_from_oz, i)
@@ -239,3 +243,58 @@ separate_define_relation <- function(
   return(terms)
   
 }
+
+previous_layers <- function(layer)
+{
+  
+  inbn <- layer$`_inbound_nodes`
+  if(length(inbn)>1)
+    stop("previous_layer function does not work on layers with multiple inbound nodes.")
+  return(inbn[[1]]$inbound_layers)
+  
+}
+
+#' Orthogonalize a Semi-Structured Model Post-hoc
+#' 
+#' @param mod deepregression model
+#' @param name_penult character name of the penultimate layer 
+#' of the deep part part
+#' @param param_nr integer; number of the parameter to be returned
+#' 
+#' @return a \code{deepregression} object with weights frozen and
+#' deep part specified by \code{name_penult} orthogonalized
+#' 
+orthog_post_fitting <- function(mod, name_penult, param_nr = 1)
+{
+  
+  mod_new_keras <- tf$keras$models$clone_model(mod$model)
+  
+  # check if model is distributional with concat before
+  ll <- mod$model$layers[[length(mod$model$layers)]]
+  if(grepl("distribution_lambda", ll$name) & 
+     grepl("concatenate", previous_layers(ll)$name)
+  ){
+    
+    concat_ll <- previous_layers(ll)
+    dist_param_outputs <- previous_layers(concat_ll)
+    
+    pll <- dist_param_outputs[[param_nr]]
+    
+    if(grepl("^add\\_", pll$name)){
+      ppll <- previous_layers(pll)
+      deep <- which(sapply(ppll, "[[", "name")==name_penult)
+      warning("Function is currently only returning the unstructured layer.")
+      return(ppll[[deep]])
+    }else{
+      stop("Model has no sum in the last layer.")
+    }
+
+  }else{
+   
+    stop("Not implemented for last layer '", gsub("\\_[0-9]+", "", ll$name),
+         "' with previous layer '", 
+         gsub("\\_[0-9]+", "", ll$`_inbound_nodes`[[1]]$inbound_layers$name),
+         "'.")
+    
+  }
+}
\ No newline at end of file
